#!/usr/bin/env python2.5
import sys
from mms import message
from mms import mms_pdu
from mms.message import MMSMessage
from mms.mms_pdu import MMSDecoder
import os
import wappushhandler as PUSH
import array

if __name__ == '__main__':
	if len(sys.argv) != 2:
		print 'Usage: %s MESSAGE_FILE' % sys.argv[0]
		sys.exit(1)

	# Decode the specified file
	fname = sys.argv[1]
	
	f = open(fname, 'rb')
	len = os.stat(fname)[6]
	data2 = array.array('B')
	data2.read(f, len)
	print data2
	data = []
	for b in data2:
		data.append(b)
	
	#data.append(0x00)
	#data.append(0)
	#print data
	#decoder = mms_pdu.MMSDecoder()
	#wspdata = decoder.decodeData(data)
	decoder = mms_pdu.MMSDecoder()
	message = decoder.decodeResponseHeader(data)
	print message
	
	
	
    